==> interactive-style-0.0.8.tgz: package/src/components/Info/index.js <==
import React, { Fragment } from 'react';
import classnames from 'classnames';
import dateFnsFormat from 'date-fns/format';

import styles from './styles.scss'

const makeBylines = authors => {
  const output = authors.slice();
  const lastAuthor = output.pop();
  const secondToLastAuthor = output.pop();

  return (
    <Fragment>
      {output.map((author, i) =>
        <Fragment key={i}>
          <a href={author.link}><span className='byline' dangerouslySetInnerHTML={{ __html: author.name }} /></a>,&nbsp;
        </Fragment>
      )}

      {secondToLastAuthor &&
        <Fragment>
          <a href={secondToLastAuthor.link}><span className='byline' dangerouslySetInnerHTML={{ __html: secondToLastAuthor.name }} /></a>
          &nbsp;and&nbsp;
        </Fragment>
      }

      <a href={lastAuthor.link}><span className='byline' dangerouslySetInnerHTML={{ __html: lastAuthor.name }} /></a>
    </Fragment>
  );
};

const formatDate = date => {
  if (typeof date === 'string') {
    const dateString = dateFnsFormat(new Date(date), 'MM/DD/YYYY h:mm A');
    return `${dateString} EST`;
  } else {
    return '';
  }
};

class Info extends React.PureComponent {
  render() {
    const { authors, published, updated } = this.props;

    return (
      <div className={classnames('info', styles.styles)}>
        <p>
          {authors && authors.length > 0 && <span className='authors'> By {makeBylines(authors)}</span> } {published && <span className='timestamp'> | <time dateTime={published}>{formatDate(published)}</time></span> } {updated && <span className='updated'>| <time dateTime={updated}>Updated {formatDate(updated)}</time></span>}
        </p>
      </div>
    );
  }
}

Info.defaultProps = {
  authors: [],
  published: null,
  updated: null,
};

export default Info;

==> interactive-style-1.0.0.tgz: package/src/components/Info/index.js <==
import React, { Fragment } from 'react';
import classnames from 'classnames';
import dateFnsFormat from 'date-fns/format';

import styles from './styles.scss';

const makeBylines = authors => {
  const output = authors.slice();
  const lastAuthor = output.pop();
  const secondToLastAuthor = output.pop();

  return (
    <Fragment>
      {output.map((author, i) =>
        <Fragment key={i}>
          <a href={author.link}><span className='byline' dangerouslySetInnerHTML={{ __html: author.name }} /></a>,&nbsp;
        </Fragment>
      )}

      {secondToLastAuthor &&
        <Fragment>
          <a href={secondToLastAuthor.link}><span className='byline' dangerouslySetInnerHTML={{ __html: secondToLastAuthor.name }} /></a>
          &nbsp;and&nbsp;
        </Fragment>
      }

      <a href={lastAuthor.link}><span className='byline' dangerouslySetInnerHTML={{ __html: lastAuthor.name }} /></a>
    </Fragment>
  );
};

const formatDate = date => {
  if (typeof date === 'string') {
    const dateString = dateFnsFormat(new Date(date), 'MM/DD/YYYY h:mm A');
    return `${dateString} EST`;
  } else {
    return '';
  }
};

class Info extends React.PureComponent {
  render() {
    const { authors, published, updated } = this.props;

    return (
      <div className={classnames('info', styles.styles)}>
        <p>
          {authors && authors.length > 0 && <span className='authors'> By {makeBylines(authors)}</span> }

          {published && updated && <span className='timestamp'> | {formatDate(published)}</span> }
          {published && !updated && <span className='timestamp'> | <time dateTime={published}>{formatDate(published)}</time></span> }

          {updated && <span className='updated'> | <time dateTime={updated}>Updated {formatDate(updated)}</time></span> }
        </p>
      </div>
    );
  }
}

Info.defaultProps = {
  authors: [],
  published: null,
  updated: null,
};

export default Info;
